@@ -113,7 +113,7 @@ class BaseApiWrapper:
         )
         return headers_dict
 
-    def get_page(self, page: int = 1, select=None, request_filter=None, order_by=None, annotations=None):
+    def get_page(self, page: int = 1, select=None, request_filter=None, order_by=None, annotations=None, query_dict=None):
         """
         Used for getting a first page of list API data,
         or a specific page if such page url has been cached.
@@ -142,6 +142,8 @@ class BaseApiWrapper:
                 params['$filter'] = request_filter
             if order_by:
                 params['$orderby'] = order_by
+            if query_dict:
+                params.update(query_dict)
         else:
             if self.page_urls.get(page) == '__none__':
                 raise D36pApiWrapperError(f'The page you requested is out of range.')
@@ -172,7 +174,7 @@ class BaseApiWrapper:
                                       'call "get_page()" method or make sure the current page is not first.')
         return self.get_page(page=self.current_page + 1)
 
-    def get_top(self, qty: int, select=None, request_filter=None, order_by=None, annotations=None):
+    def get_top(self, qty: int, select=None, request_filter=None, order_by=None, annotations=None, query_dict=None):
         """
         :raises D365ApiError: if http request is not "Ok"
         :param qty: the number of matching results to return
@@ -189,6 +191,8 @@ class BaseApiWrapper:
             params['$filter'] = request_filter
         if order_by:
             params['$orderby'] = order_by
+        if query_dict:
+            params.update(query_dict)
         headers = self.headers.copy()
         if annotations:
             headers = self._update_prefer_header(headers, 'odata.include-annotations', f'"{annotations}"')
@@ -211,10 +215,12 @@ class BaseApiWrapper:
             headers = self._update_prefer_header(headers, 'odata.include-annotations', f'"{annotations}"')
         return requests.post(self.api_url, headers=headers, json=json.dumps(data))
 
-    def retrieve(self, entity_id, select=None, annotations=None):
+    def retrieve(self, entity_id, select=None, annotations=None, query_dict=None):
         params = {}
         if select:
             params['$select'] = select
+        if query_dict:
+            params.update(query_dict)
         headers = self.headers.copy()
         if annotations:
             headers = self._update_prefer_header(headers, 'odata.include-annotations', f'"{annotations}"')
